arrc.callbacks
==============

.. automodule:: arrc.callbacks

   
.. rubric:: Modules

.. autosummary::
   :toctree:
   :recursive:

   histogram_visualizer
   tsne_visualizer_callback
   umap_visualizer_callback
   visualizer_callback
